import React from "react";
import { act } from "react-dom/test-utils";
import Enzyme, { mount } from "enzyme";
import Adapter from "enzyme-adapter-react-16";
import { SplitFactory, SplitTreatments } from "@splitsoftware/splitio-react";

Enzyme.configure({ adapter: new Adapter() });

describe("switchio isReady minimal test case", () => {
    const expectedText = "on";
    const notReadyText = "Not Ready";
    const feature_1 = 'clients';

    const config = {
        core: {
            authorizationKey: "localhost",
            key: 'react-guy',
        },
        features: {
            'clients': 'on',
            'sample_features': 'off'
        },
        scheduler: {
            offlineRefreshRate: 15
        },
        debug: true,
    };

    it("is ready", async () => {
        let wrapper;
        await act(async () => {
            wrapper = mount(
                <SplitFactory config={config} updateOnSdkTimedout={true}>
                    <SplitTreatments names={[feature_1]}>
                        {({ treatments, isReady }) =>
                            isReady
                                ? treatments.clients.treatment
                                : notReadyText

                        }
                    </SplitTreatments>
                </SplitFactory>
            );
        });

        expect(wrapper.html().includes(expectedText)).toBe(false);
        expect(wrapper.html().includes(notReadyText)).toBe(true);

        wrapper.update();
        expect(wrapper.html().includes(expectedText)).toBe(true);
        expect(wrapper.html().includes(notReadyText)).toBe(false);

    });
});
